docker run --rm \
	-v $SOURCEDIR:/source \
	-v $OUTPUTDIR:/nightly \
	localghost/ezquake_nightly

